==> kuehn_et_al_fdm-1.0.1.tar.gz: kuehn_et_al_fdm-1.0.1/README.md <==
# kuehn_et_al_fdm

![CI](https://github.com/asarmy/kuehn_et_al_fdm/actions/workflows/CI.yml/badge.svg)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
![Coverage](https://github.com/asarmy/kuehn_et_al_fdm/raw/coverage-data-branch/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/kuehn-et-al-fdm/badge/?version=latest)](https://kuehn-et-al-fdm.readthedocs.io/en/latest/)
[![DOI](https://zenodo.org/badge/841573158.svg)](https://zenodo.org/doi/10.5281/zenodo.13308173)
<!--
![Test PyPI](https://img.shields.io/badge/test-pypi-v1.0.0-blue)
![Downloads](https://img.shields.io/badge/test-pypi-downloads-lightgrey)
-->

## Overview

Python Implementation of the Kuehn et al. (2024) Fault Displacement Model.

The model is documented in:
> Kuehn NM, Kottke AR, Sarmiento AC, Madugo CM and Bozorgnia Y (2024). A fault displacement model based on the FDHI database: *Earthquake Spectra*, Epub ahead of print, DOI: 10.1177/87552930241291077.


To install the package, follow the instructions in the [Installation Guide](https://kuehn-et-al-fdm.readthedocs.io/en/latest/installation.html).

See the [Quick Usage Guide](https://kuehn-et-al-fdm.readthedocs.io/en/latest/usage.html) to get started.

## License

This project is licensed under the MIT License. See the [LICENSE](https://github.com/asarmy/kuehn_et_al_fdm/blob/main/LICENSE) file for details.

## Citing this Work

If you use this software in your research, please cite it using the following DOI: [![DOI](https://zenodo.org/badge/841573158.svg)](https://zenodo.org/doi/10.5281/zenodo.13308173).

==> kuehn_et_al_fdm-1.0.2.tar.gz: kuehn_et_al_fdm-1.0.2/README.md <==
# kuehn_et_al_fdm

![CI](https://github.com/asarmy/kuehn_et_al_fdm/actions/workflows/CI.yml/badge.svg)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
![Coverage](https://github.com/asarmy/kuehn_et_al_fdm/raw/coverage-data-branch/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/kuehn-et-al-fdm/badge/?version=latest)](https://kuehn-et-al-fdm.readthedocs.io/en/latest/)
[![DOI](https://zenodo.org/badge/841573158.svg)](https://zenodo.org/doi/10.5281/zenodo.13308173)
[![PyPI version](https://img.shields.io/pypi/v/fdhpy.svg)](https://pypi.org/project/kuehn-et-al-fdm/)
![Downloads](https://pepy.tech/badge/kuehn-et-al-fdm)

## Overview

Python Implementation of the Kuehn et al. (2024) Fault Displacement Model.

The model is documented in:
> Kuehn NM, Kottke AR, Sarmiento AC, Madugo CM and Bozorgnia Y (2024). A fault displacement model based on the FDHI database: *Earthquake Spectra*, Epub ahead of print, DOI: 10.1177/87552930241291077.


To install the package, follow the instructions in the [Installation Guide](https://kuehn-et-al-fdm.readthedocs.io/en/latest/installation.html).

See the [Quick Usage Guide](https://kuehn-et-al-fdm.readthedocs.io/en/latest/usage.html) to get started.

## License

This project is licensed under the MIT License. See the [LICENSE](https://github.com/asarmy/kuehn_et_al_fdm/blob/main/LICENSE) file for details.

## Citing this Work

If you use this software in your research, please cite it using the following DOI: [![DOI](https://zenodo.org/badge/841573158.svg)](https://zenodo.org/doi/10.5281/zenodo.13308173).
